import os
import sys

def create(service_name):
    service_template = f"""
from service_layer.service import Service

class {service_name}(Service):
    def setup(self):
        pass

    def handle(self):
        raise NotImplementedError
    """

    # Ensure the 'services' directory exists
    directory = "services"
    if not os.path.exists(directory):
        os.makedirs(directory)

    file_path = f"{directory}/{service_name}.py"

    with open(file_path, "w") as file:
        file.write(service_template)

    print(f"Service '{service_name}' created at {file_path}")


def main():
    if len(sys.argv) != 3 or sys.argv[1] != "create":
        print("Usage: python service.py create <ServiceName>")
        sys.exit(1)

    command, service_name = sys.argv[1], sys.argv[2]
    if command == "create":
        create(service_name)

if __name__ == "__main__":
    main()


from setuptools import setup, find_packages

setup(
    name="layered-py",
    version="1.0.2",
    description="A Python library for implementing layered architecture with services and dependency injection.",
    long_description=open("README.md", "r", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    author="Malte Harms",
    author_email="mail@malteharms.dev",
    url="https://github.com/upNorthDev/LayeredPy",
    packages=find_packages(exclude=["tests*", "*.tests"]),
    include_package_data=True,
    python_requires=">=3.7",
    install_requires=[],
    entry_points={
        "console_scripts": [
            "service=cli.service:main"
        ],
    },

    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    keywords="layered architecture, services, dependency injection, python",
    project_urls={
        "Bug Tracker": "https://github.com/upNorthDev/LayeredPy/issues",
        "Documentation": "https://github.com/upNorthDev/LayeredPy",
        "Source Code": "https://github.com/upNorthDev/LayeredPy",
    },
)
